@@ -3,12 +3,12 @@ import hmac
 import json
 from uuid import UUID
 
-from octokit import utils
+from octokit_routes import webhook_names
 
 
 def valid_signature(headers, payload, secret):
-    encoding = 'utf-8'
-    algo, sig = headers.get('X-Hub-Signature').split('=')
+    encoding = "utf-8"
+    algo, sig = headers.get("X-Hub-Signature").split("=")
     digest = hmac.new(secret.encode(encoding), payload.encode(encoding), getattr(hashlib, algo)).hexdigest()
     return hmac.compare_digest(sig.encode(encoding), digest.encode(encoding))
 
@@ -21,19 +21,19 @@ def valid_guid(guid):
 
 
 def valid_event(event, events):
-    return event in utils.get_json_data('events.json') and (event in events or '*' in events)
+    return event in webhook_names or "*" in webhook_names
 
 
 def valid_user_agent(ua):
-    return ua.startswith('GitHub-Hookshot/')
+    return ua.startswith("GitHub-Hookshot/")
 
 
 def valid_headers(headers, events, verify_user_agent):
-    if not valid_guid(headers.get('X-GitHub-Delivery')):
+    if not valid_guid(headers.get("X-GitHub-Delivery")):
         return False
-    if not valid_event(headers.get('X-GitHub-Event'), events):
+    if not valid_event(headers.get("X-GitHub-Event"), events):
         return False
-    if verify_user_agent and not valid_user_agent(headers.get('User-Agent', '')):
+    if verify_user_agent and not valid_user_agent(headers.get("User-Agent", "")):
         return False
     return True
 
@@ -42,6 +42,6 @@ def verify(headers, payload, secret, events=None, verify_user_agent=False, retur
     if not valid_headers(headers, events, verify_user_agent):
         return False
     validity = valid_signature(headers, payload, secret)
-    if validity and return_app_id and headers.get('X-GitHub-Event') == 'ping':
-        return json.loads(payload).get('hook').get('app_id')
+    if validity and return_app_id and headers.get("X-GitHub-Event") == "ping":
+        return json.loads(payload).get("hook").get("app_id")
     return validity
